@@ -1,5 +1,5 @@
 use crate::error::Error;
-use chrono::{offset::TimeZone, DateTime, Utc};
+use std::time::SystemTime;
 
 /// Represents a token as returned by `OAuth2` servers.
 ///
@@ -23,23 +23,21 @@ pub struct Token {
     /// Prefer using expiry_date()
     pub expires_in: Option<i64>,
     /// timestamp is seconds since epoch indicating when the token will expire
-    /// in absolute terms. use [`Self::expiry_date`] to convert to DateTime.
-    pub expires_in_timestamp: Option<i64>,
+    /// in absolute terms.
+    pub expires_in_timestamp: Option<SystemTime>,
 }
 
 impl Token {
     /// Returns true if we are expired.
     #[inline]
     pub fn has_expired(&self) -> bool {
-        self.access_token.is_empty() || self.expiry_date() <= Utc::now()
-    }
-
-    /// Returns a [`chrono::DateTime`] object representing our expiry date.
-    pub fn expiry_date(&self) -> DateTime<Utc> {
-        match self.expires_in_timestamp {
-            Some(ts) => Utc.timestamp(ts, 0),
-            None => Utc::now(),
+        if self.access_token.is_empty() {
+            return true;
         }
+
+        let expiry = self.expires_in_timestamp.unwrap_or_else(SystemTime::now);
+
+        expiry <= SystemTime::now()
     }
 }
 
